aboutsummaryrefslogtreecommitdiff
path: root/libbuild2/context.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'libbuild2/context.hxx')
-rw-r--r--libbuild2/context.hxx3
1 files changed, 2 insertions, 1 deletions
diff --git a/libbuild2/context.hxx b/libbuild2/context.hxx
index 0595413..fbdf9b8 100644
--- a/libbuild2/context.hxx
+++ b/libbuild2/context.hxx
@@ -46,7 +46,8 @@ namespace build2
// Statistics.
//
public:
- size_t contention = 0; // # of contentious phase (re)locks.
+ size_t contention = 0; // # of contentious phase (re)locks.
+ size_t contention_load = 0; // # of contentious load phase locks.
private:
friend class context;